"""
Django settings for chai_django project.

Generated by 'django-admin startproject' using Django 1.10.1.

For more information on this file, see
https://docs.djangoproject.com/en/1.10/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.10/ref/settings/
"""

import os


from django_framework.django_helpers.settings_helper.settings_configuration import PrivateSetting

class ProjectSetting(PrivateSetting):
    # basic things about the project!
    # these are typically django related! and very core
    _PROJECT_NAME = 'django_framework_project'
    _SECRET_KEY = 'r%z^)v_=p7tcb0py7xxi(uy)jleo=v&39_bcxo#(82)mj#if4g'
    
    _DATABASE_SERVER = {
                        'default': {
                    
                            'ENGINE': 'django.db.backends.mysql',
                            'NAME': 'chai_django_db2',
                            'USER': 'root',
                            'PASSWORD': '',
                            'HOST': '127.0.0.1',
                            'PORT': '3306',
                        }
                    }
    
    # defines settings on messages
    _DEBUG = True
    _SHOW_DEBUG_TRACEBACK = True
    _SHOW_DEBUG_ERROR = False
    
    # encryption related and related to how the django_framework runs!
    _TRIPLE_DES_TOKEN_KEY = '0a405340000b493d8cf0' # this is used to encrypt your tokens so this really cant ever change!
    _TRIPLE_DES_TOKEN_IV = None # this is used to encrypt your tokens so this really cant ever change!
    
    # redis settings
    _REDIS_SERVER = {
                    "default": {
                        "BACKEND": "django_redis.cache.RedisCache",
                        "LOCATION": "redis://127.0.0.1:6379/1",
                        "OPTIONS": {
                            "CLIENT_CLASS": "django_redis.client.DefaultClient",
                        }
                    }
                }
    
    # kafka settings
    _KAFKA_SERVER = None # if set, will also set KAFKA_ENABLED = True
    
    # chai specific settings:
    _IS_AUTHENTICATION_SERVER = True  # flag is used to determine if this server is allowed to verify integrity of Token
    _AUTHENTICATION_SHOULD_PASSTHROUGH = True
    
    # chai sending jobs
    _ALLOW_SEND_JOBS = True
    _SEND_JOB_URL = 'https://redisapi.chaienergy.net/set_job/?format=json'
    _JOB_REPLY_URL = 'https://redisapi.chaienergy.net/set_job/?format=json' # typically the same one as "as the server group url"

    _ENCRYPTION_SALT = None # shoudl be set to something
    
    
    _CHECK_MODEL_DATA_WITH_PERMISSIONS = False
    _GET_MODEL_WITH_PERMISSIONS = False

project_settings = ProjectSetting()

PROJECT_NAME = project_settings.PROJECT_NAME

DEBUG = project_settings.DEBUG
SHOW_DEBUG_ERROR =     project_settings.SHOW_DEBUG_ERROR
SHOW_DEBUG_TRACEBACK =     project_settings.SHOW_DEBUG_TRACEBACK


SECRET_KEY = project_settings.SECRET_KEY


ALLOWED_HOSTS = ['*']
INTERNAL_IPS = ['127.0.0.1']

DATABASES = project_settings.DATABASE_SERVER

# used by encryption serializer
ENCRYPTION_KEY = project_settings.TRIPLE_DES_TOKEN_KEY # this is used to encrypt your tokens so this really cant ever change!
ENCRYPTION_IV  = project_settings.TRIPLE_DES_TOKEN_IV
ENCRYPTION_SALT = project_settings.ENCRYPTION_SALT
PRIVATE_TRIPLE_DES_TOKEN_KEY = project_settings.TRIPLE_DES_TOKEN_KEY

IS_AUTHENTICATION_SERVER = project_settings.IS_AUTHENTICATION_SERVER  # flag is used to determine if this server is allowed to verify integrity of Token
AUTHENTICATION_SHOULD_PASSTHROUGH = project_settings.AUTHENTICATION_SHOULD_PASSTHROUGH

REDIS_CACHE_ENABLED = project_settings.REDIS_ENABLED
CACHES = project_settings.REDIS_SERVER

KAFKA_ENABLED = project_settings.KAFKA_ENABLED


ALLOW_SEND_JOBS = project_settings.ALLOW_SEND_JOBS
SEND_JOB_URL = project_settings.SEND_JOB_URL
JOB_REPLY_URL = project_settings.JOB_REPLY_URL


GET_MODEL_WITH_PERMISSIONS = project_settings.GET_MODEL_WITH_PERMISSIONS
CHECK_MODEL_DATA_WITH_PERMISSIONS = project_settings.CHECK_MODEL_DATA_WITH_PERMISSIONS



SERVER_URL = 'localhost'
SERVER_GROUP = 'service'
SERVER_NAME = 'service1'